NetworkX 1.7
============

Release date:  4 July 2012

Highlights
~~~~~~~~~~

- New functions for k-clique community finding, flow hierarchy,
  union, disjoint union, compose, and intersection operators that work on
  lists of graphs, and creating the biadjacency matrix of a bipartite graph.

- New approximation algorithms for dominating set, edge dominating set,
  independent set, max clique, and min-weighted vertex cover.

- Many bug fixes and other improvements.

For full details of the tickets closed for this release (added features and bug fixes) see:
https://networkx.lanl.gov/trac/query?status=closed&group=milestone&milestone=networkx-1.7

Other
-----
* Untested bipartite_random_regular_graph() removed.

